"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Loader = void 0;
const image_utils_1 = require("../../utils/image-utils");
const coco_1 = require("./coco");
class Loader {
    constructor(log) {
        this.log = log;
    }
    async loadCoco(useFullModel = false) {
        const printProcessDuration = (name, start) => {
            this.log.debug(name + ' processing took: ' + (Date.now() - start) + 'ms');
        };
        const printResults = (results) => {
            if (results && results.length > 0) {
                for (const result of results) {
                    this.log.debug('==> Detected: ' + result.class + ' [' + Math.round(result.score * 100) + '%]');
                }
            }
            else {
                this.log.debug('Nothing detected!');
            }
        };
        const model = await (0, coco_1.load)({ base: useFullModel ? 'mobilenet_v2' : 'lite_mobilenet_v2' });
        return {
            async detect(image) {
                const start = Date.now();
                const canvas = image_utils_1.ImageUtils.createCanvasFromImage(image);
                const results = await model.detect(canvas);
                printProcessDuration('COCO', start);
                printResults(results);
                return results;
            }
        };
    }
}
exports.Loader = Loader;
//# sourceMappingURL=loader.js.map