"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RtpUtils = exports.RtpDemuxer = void 0;
const dgram_1 = require("dgram");
const get_port_1 = __importDefault(require("get-port"));
class RtpDemuxer {
    constructor(streamingDelegate, ipFamily, inputPort, rtcpPort, rtpPort) {
        this.delegate = streamingDelegate;
        this.log = streamingDelegate.log;
        this.inputPort = inputPort;
        this.socket = (0, dgram_1.createSocket)(ipFamily === 'ipv6' ? 'udp6' : 'udp4');
        this.socket.on('error', (error) => {
            this.log.error('%s: RTPSplitter Error: %s', this.delegate.cameraName, error);
            this.socket.close();
        });
        this.socket.on('message', (msg) => {
            if (this.isRtpMessage(msg)) {
                this.socket.send(msg, rtpPort);
            }
            else {
                this.heartbeatMsg = Buffer.from(msg);
                clearTimeout(this.heartbeatTimer);
                this.heartbeat(rtpPort);
                this.socket.send(msg, rtcpPort);
            }
        });
        this.socket.bind(this.inputPort);
    }
    heartbeat(port) {
        clearTimeout(this.heartbeatTimer);
        this.heartbeatTimer = setTimeout(() => {
            this.socket.send(this.heartbeatMsg, port);
            this.heartbeat(port);
        }, 3.5 * 1000);
    }
    close() {
        clearTimeout(this.heartbeatTimer);
        this.socket.close();
    }
    getPayloadType(message) {
        return message.readUInt8(1) & 0x7f;
    }
    isRtpMessage(message) {
        const payloadType = this.getPayloadType(message);
        return (payloadType > 90) || (payloadType === 0);
    }
}
exports.RtpDemuxer = RtpDemuxer;
class RtpUtils {
    static async reservePorts(count = 1) {
        const port = await (0, get_port_1.default)();
        const ports = [port];
        for (let i = 1; i < count; i++) {
            const targetConsecutivePort = port + i;
            const openPort = await (0, get_port_1.default)({ port: targetConsecutivePort });
            if (openPort !== targetConsecutivePort) {
                return this.reservePorts(count);
            }
            ports.push(openPort);
        }
        return ports;
    }
}
exports.RtpUtils = RtpUtils;
//# sourceMappingURL=rtp-splitter.js.map