"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Mqtt = void 0;
const mqtt = require('mqtt');
class Mqtt {
    constructor(config, log) {
        var _a, _b;
        this.log = log;
        this.config = config;
        if (!config || !config.broker) {
            return;
        }
        const options = {};
        if (config.username) {
            options.username = config.username;
            if (config.password) {
                options.password = config.password;
            }
        }
        this.client = mqtt.connect(config.broker, options);
        (_a = this.client) === null || _a === void 0 ? void 0 : _a.on('connect', () => {
            this.log.debug('Connected to MQTT broker');
        });
        (_b = this.client) === null || _b === void 0 ? void 0 : _b.on('error', (error) => {
            this.log.error('MQTT error: ' + error.message);
        });
    }
    sendMessageOnTopic(message, topic) {
        var _a;
        if ((_a = this.client) === null || _a === void 0 ? void 0 : _a.connected) {
            this.client.publish(this.config.topicPrefix + '/' + topic, message);
        }
    }
    onConnection() {
        return new Promise((resolve, reject) => {
            let interval = setInterval(() => {
                var _a;
                if ((_a = this.client) === null || _a === void 0 ? void 0 : _a.connected) {
                    clearInterval(interval);
                    resolve();
                }
            }, 10);
        });
    }
    subscribeToTopic(topic, callback) {
        this.onConnection().then(() => {
            var _a;
            this.log.debug('Subscribing to: ' + this.config.topicPrefix + '/' + topic);
            (_a = this.client) === null || _a === void 0 ? void 0 : _a.subscribe(this.config.topicPrefix + '/' + topic, (err, granted) => {
                var _a;
                console.log(granted);
                if (!err) {
                    if (granted && granted.length === 1) {
                        (_a = this.client) === null || _a === void 0 ? void 0 : _a.on('message', (messageTopic, messagePayload, packet) => {
                            if (messageTopic === this.config.topicPrefix + '/' + topic) {
                                callback(JSON.parse(messagePayload.toString()));
                            }
                        });
                    }
                }
            });
        });
    }
}
exports.Mqtt = Mqtt;
//# sourceMappingURL=mqtt.js.map